@@ -45,6 +45,7 @@
 #include <inti/gtk/menuitem.h>
 #include <inti/gtk/optionmenu.h>
 #include <inti/gtk/paned.h>
+#include <inti/gtk/progressbar.h>
 #include <inti/gtk/radiobutton.h>
 #include <inti/gtk/radiomenuitem.h>
 #include <inti/gtk/rc.h>
@@ -143,7 +144,7 @@ LabelTest::LabelTest ()
   vbox ()->pack_start (label, true, true, 5);
   
   label = new Label (_("By default labels are center-justified\nand center-aligned,\nlike this"));
-  vbox ()->pack_start (label, true, true, 5);  
+  vbox ()->pack_start (label, true, true, 5);
 
   label = new Label (_("This is a multiline label\nand it's\nleft justified\nand left-aligned"));
   label->set_justify (JUSTIFY_LEFT);
@@ -188,18 +189,18 @@ protected:
   ~AlphaEntry () {} 
 
   // override this implementation in order to filter out digits.
-  virtual void insert_text_impl (const string & text, int * position);
+  virtual void insert_text_impl (const ustring & text, int * position);
 
 };
 
-void AlphaEntry::insert_text_impl (const string & text, int * position)
+void AlphaEntry::insert_text_impl (const ustring & text, int * position)
 {
   using namespace Gtk;
     
   bool found_digits = false;
   string real_text;
-  string::const_iterator i = text.begin ();
-  while (i != text.end ())
+  string::const_iterator i = text.str ().begin ();
+  while (i != text.str ().end ())
     {
       if (isdigit (*i))
         found_digits = true;
@@ -239,7 +240,7 @@ EntryTest::EntryTest ()
 
   entry = new Entry;
   entry->set_text (_("MyPassword"));
-  entry->set_password_mode (false);
+  entry->set_visibility (false);
   vbox ()->pack_start (entry, true, true, 5);
 
   entry = new Entry;
@@ -675,7 +676,7 @@ ScaleTest::on_entry_changed (Gtk::Adjustment * adj)
 {
   using namespace Gtk;
   
-  string text (entry_->text ());
+  ustring text (entry_->text ());
   
   float f = atof (text.c_str ());
   
@@ -718,6 +719,75 @@ PanedTest::PanedTest ()
   vbox ()->show_all ();
 }
 
+
+/////////////////////////////////////////////////////
+
+class ProgressBarTest : public TestWindow
+{
+public:
+  ProgressBarTest ();
+
+protected:
+  ~ProgressBarTest ();
+  
+private:
+  ptr<Gtk::ProgressBar> bar_1_;
+  ptr<Gtk::ProgressBar> bar_2_;
+  Connection timeout_1_;
+  Connection timeout_2_;
+
+  bool on_timeout_1 ();
+  bool on_timeout_2 ();
+};
+
+ProgressBarTest::ProgressBarTest ()
+  : bar_1_ (new Gtk::ProgressBar),
+    bar_2_ (new Gtk::ProgressBar)
+{
+  using namespace Gtk;
+  
+  vbox ()->pack_start (bar_1_, false, false, 5);
+  vbox ()->pack_start (bar_2_, false, false, 5);
+
+  timeout_1_ = Main::get ()->connect_timeout (500,
+                                              slot (this,
+                                                    &ProgressBarTest::on_timeout_2));
+  
+
+  timeout_2_ = Main::get ()->connect_timeout (300,
+                                              slot (this,
+                                                    &ProgressBarTest::on_timeout_1));
+  
+  vbox ()->show_all ();
+}
+
+ProgressBarTest::~ProgressBarTest ()
+{
+  timeout_1_.disconnect ();
+  timeout_2_.disconnect ();
+}
+
+bool
+ProgressBarTest::on_timeout_1 ()
+{
+  if (bar_1_->fraction () > .9)
+    bar_1_->set_fraction (0.0);
+  else
+    bar_1_->set_fraction (bar_1_->fraction () + 0.1);
+
+  bar_1_->set_text (Text::to_string (bar_1_->fraction ()));
+  
+  return true;
+}
+
+bool
+ProgressBarTest::on_timeout_2 ()
+{
+  bar_2_->pulse ();
+
+  return true;
+}
+
 /////////////////////////////////////////////////////
 
 class MenuTest : public TestWindow
@@ -1604,6 +1674,7 @@ MainWindow::MainWindow ()
   add_button ("Gtk::Menu", TestCreator<MenuTest>::create_test);
   add_button ("Gtk::OptionMenu", TestCreator<MenuTest>::create_test);
   add_button ("Gtk::Paned", TestCreator<PanedTest>::create_test);
+  add_button ("Gtk::ProgressBar", TestCreator<ProgressBarTest>::create_test);
   add_button ("Gtk::RadioButton", TestCreator<RadioButtonTest>::create_test);
   add_button ("Gtk::RcStyle", TestCreator<RcTest>::create_test);
   add_button ("Gtk::Scale", TestCreator<ScaleTest>::create_test);
