@@ -643,7 +643,7 @@ def process_make_class (outfile, indent, is_concrete, prefix, objname, funcprefi
     outfile.write_to_impl ("       };\n\n")
     outfile.write_to_impl ("       type_ = g_type_register_static (type (),\n")
     outfile.write_to_impl ("                                      \"Inti_" + prefix + "_" + objname + "\",\n")
-    outfile.write_to_impl ("                                      &info);\n")
+    outfile.write_to_impl ("                                      &info, GTypeFlags(0));\n")
     outfile.write_to_impl ("    }\n")
     outfile.write_to_impl ("  return type_;\n")
     outfile.write_to_impl ("}\n\n")
