@@ -36,3 +36,11 @@ class OutputTarget:
 
     def impl_handle (self):
         return self.impl_target
+
+    def close (self):
+        if self.header_target:
+            self.header_target.close ()
+        if self.impl_target:
+            self.impl_target.close ()
+        if self.current_target:
+            self.current_target.close ()
